@@ -83,30 +83,65 @@
 #'}
 #'
 #'
-
-beesTaxonomy <- function(URL = "https://figshare.com/ndownloader/files/42320595?private_link=bce1f92848c2ced313ee",
+beesTaxonomy <- function(URL = "https://figshare.com/ndownloader/files/42402264?private_link=bce1f92848c2ced313ee",
                          ...){
-  destfile <- taxonomy <- attempt <- NULL
+  destfile <- taxonomy <- attempt <- nAttempts <- error_funcFile <- error_func <-  NULL
 
+  # Set the number of attempts
+  nAttempts = 5
+  
+  # Set up the error message function
+  error_func <- function(e){
+    message(paste("Download attempt failed..."))
+  }
+  error_funcFile <- function(e){
+    message(paste("Could not read download..."))
+  }
+  # Check operating system
+  OS <- dplyr::if_else(.Platform$OS.type == "unix",
+                       "MacLinux",
+                       "Windows")
+  
+  
     # Run a code to download the data and deal with potential internet issues
   taxonomy <- NULL                                 
-  attempt <- 0 
+  attempt <- 1
   suppressWarnings(
-  while( is.null(taxonomy) && attempt <= 3) {    
+  while( is.null(taxonomy) && attempt <= nAttempts) {   
+    # Don't attempt for the last attempt
+    if(attempt < nAttempts){
+      
+# WINDOWS
+      if(OS != "MacLinux"){
     # Download the file to the outPath 
-    try(utils::download.file(URL, destfile = paste0(tempdir(), "/beesTaxonomy.Rda")),
-        silent = TRUE)
+    tryCatch(utils::download.file(URL, destfile = normalizePath(paste0(tempdir(), 
+                                                                       "/beesTaxonomy.Rda"))),
+        error = error_func, warning = error_func)
     # Load the file from the outPath
-    try(
-    taxonomy <- base::readRDS(paste0(tempdir(), "/beesTaxonomy.Rda")),
-    silent = TRUE)
+      tryCatch(
+    taxonomy <- base::readRDS(normalizePath(paste0(tempdir(), "/beesTaxonomy.Rda"))),
+    error = error_funcFile, warning = error_funcFile)
+      }else{
+        # Download the file to the outPath 
+        tryCatch(utils::download.file(URL, destfile = paste0(tempdir(), "/beesTaxonomy.Rda")),
+                 error = error_func, warning = error_func)
+        # Load the file from the outPath
+        tryCatch(
+          taxonomy <- base::readRDS(paste0(tempdir(), "/beesTaxonomy.Rda")),
+          error = error_funcFile, warning = error_funcFile)
+      }
+        
+        
+    } # END if
     
-      # Count the next attempt
-    attempt <- attempt + 1       
+    if(attempt < nAttempts){
       # Wait one second before the next request 
     if(attempt > 1){Sys.sleep(1)            
-      print( paste("Attempt: ", attempt, " of 4"))}    # Inform user of number of attempts
-  } 
+      print( paste("Attempt: ", attempt, " of ", nAttempts-1))}    # Inform user of number of attempts
+    } # END IF #2
+    # Count the next attempt
+    attempt <- attempt + 1   
+  } # END while
   )
   
   if(is.null(taxonomy)){
